class Djbdns < Formula
  desc "D.J. Bernstein's DNS tools"
  homepage "https://cr.yp.to/djbdns.html"
  url "https://cr.yp.to/djbdns/djbdns-1.05.tar.gz"
  sha256 "3ccd826a02f3cde39be088e1fc6aed9fd57756b8f970de5dc99fcd2d92536b48"
  license :public_domain

  livecheck do
    url "https://cr.yp.to/djbdns/install.html"
    regex(/href=.*?djbdns[._-]v?(\d+(?:\.\d+)+)\.t/i)
  end

  depends_on "daemontools"
  depends_on "ucspi-tcp"

  on_linux do
    depends_on "fakeroot" => :build
  end

  def install
    inreplace "hier.c", 'c("/"', "c(auto_home"
    inreplace "dnscache-conf.c", "/etc/dnsroots", "#{etc}/dnsroots"

    # Write these variables ourselves.
    rm %w[conf-home conf-ld conf-cc]
    (buildpath/"conf-home").write prefix
    (buildpath/"conf-ld").write "gcc"

    usr = if OS.mac? && MacOS.sdk_path_if_needed
      "#{MacOS.sdk_path}/usr"
    else
      "/usr"
    end
    # `-Wno-implicit-function-declaration` fixes compile with newer Clang
    (buildpath/"conf-cc").write "gcc -O2 -include #{usr}/include/errno.h -Wno-implicit-function-declaration"

    bin.mkpath
    (prefix/"etc").mkpath # Otherwise "file does not exist"

    # Use fakeroot on Linux because djbdns checks for setgroups permissions
    # that are limited in CI.
    if OS.mac?
      system "make", "setup", "check"
    else
      system "fakeroot", "make", "setup", "check"
    end
  end

  test do
    # Use example.com instead of localhost, because localhost does not resolve in all cases
    assert_match(/\d+\.\d+\.\d+\.\d+/, shell_output("#{bin}/dnsip example.com").chomp)
  end
end
